"use client";

import Image from "next/image";
import { useCallback, useEffect, useState } from "react";

import useEmblaCarousel from "embla-carousel-react";
import { ArrowLeft, ArrowRight } from "lucide-react";

import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { Certificate } from "@/utils/get-fake-data";

import Progressbar from "../common/progress-bar";

interface CertificateCarouselProps {
	items: Certificate[];
	locale: Locale;
	headerTitle: Record<string, string>;
	headerDescription: Record<string, string>;
}

export function CertificateCarousel({
	items,
	headerTitle,
	locale,
	headerDescription,
}: CertificateCarouselProps) {
	const isRTL = locale === "ar";
	const [currentSlide, setCurrentSlide] = useState(0);
	const [canScrollPrev, setCanScrollPrev] = useState(false);
	const [canScrollNext, setCanScrollNext] = useState(true);

	const [emblaRef, emblaApi] = useEmblaCarousel({
		align: "start",
		direction: isRTL ? "rtl" : "ltr",
		dragFree: true,
		containScroll: "trimSnaps",
		slidesToScroll: 1,
		breakpoints: {
			"(min-width: 768px)": { slidesToScroll: 2 },
			"(min-width: 1024px)": { slidesToScroll: 2 },
		},
	});

	const scrollPrev = useCallback(() => emblaApi?.scrollPrev(), [emblaApi]);
	const scrollNext = useCallback(() => emblaApi?.scrollNext(), [emblaApi]);

	const onSelect = useCallback(() => {
		if (!emblaApi) return;
		setCurrentSlide(emblaApi.selectedScrollSnap());
		setCanScrollPrev(emblaApi.canScrollPrev());
		setCanScrollNext(emblaApi.canScrollNext());
	}, [emblaApi]);

	useEffect(() => {
		if (!emblaApi) return;
		onSelect();
		emblaApi.on("select", onSelect);
		emblaApi.on("reInit", onSelect);
		return () => {
			emblaApi.off("select", onSelect);
			emblaApi.off("reInit", onSelect);
		};
	}, [emblaApi, onSelect]);

	return (
		<section
			className={`${locale === "ar" ? "lg:pr-12" : "lg:pl-12"} overflow-hidden bg-white px-4 py-16`}
		>
			<div className="container mx-auto">
				{/* Header */}
				<div className="mb-12 flex items-center justify-between">
					<h2
						className={cn(
							"flex-[40%] text-4xl text-custom-primary-accent",
							isRTL && "text-right"
						)}
					>
						{headerTitle?.[locale]}
					</h2>
					<p
						className={cn(
							"flex-[60%] text-custom-primary-accent",
							isRTL && "text-right"
						)}
					>
						{headerDescription?.[locale]}
					</p>
				</div>

				{/* Carousel */}
				<div className="relative">
					<div className="overflow-hidden" ref={emblaRef}>
						<div className="flex">
							{items?.map((item) => (
								<div
									key={item.id}
									className="relative mr-6 min-w-0 flex-[0_0_100%] md:flex-[0_0_calc(50%-24px)] lg:flex-[0_0_calc(40%-24px)]"
								>
									<div className="relative aspect-[16/11]">
										<Image
											src={item.image}
											alt={item.title?.[locale]}
											fill
											className="rounded-lg object-cover"
										/>
										<div className="absolute bottom-0 right-0 max-w-[300px] rounded-lg bg-white/90 p-4 backdrop-blur">
											<div className="flex items-center gap-3">
												<span className="text-2xl text-blue-500">
													{item.icon}
												</span>
												<p className="text-sm text-gray-800">
													{item.description?.[locale]}
												</p>
											</div>
										</div>
									</div>
								</div>
							))}
						</div>
					</div>

					{/* Navigation */}
					<div className="mt-8 flex items-center justify-between">
						{/* Progress */}
						<div className="flex items-center gap-4">
							<span className="text-3xl font-bold text-blue-500">
								{(currentSlide + 1).toString().padStart(2, "0")}
							</span>
							<div className="w-40">
								<Progressbar
									progress={((currentSlide + 1) / items.length) * 100}
									progressColor="#2895c8"
									height="h-2"
									dir={isRTL ? "rtl" : "ltr"}
								/>
							</div>
						</div>

						<div className="flex items-center gap-4">
							<button
								onClick={scrollPrev}
								className={cn(
									"flex h-12 w-12 items-center justify-center rounded-lg border-2 transition-all",
									canScrollPrev
										? "border-blue-500 text-blue-500 hover:bg-blue-50"
										: "border-gray-300 text-gray-300"
								)}
								disabled={!canScrollPrev}
							>
								{isRTL ? (
									<ArrowRight className="h-6 w-6" />
								) : (
									<ArrowLeft className="h-6 w-6" />
								)}
							</button>
							<button
								onClick={scrollNext}
								className={cn(
									"flex h-12 w-12 items-center justify-center rounded-lg border-2 transition-all",
									canScrollNext
										? "border-blue-500 text-blue-500 hover:bg-blue-50"
										: "border-gray-300 text-gray-300"
								)}
								disabled={!canScrollNext}
							>
								{isRTL ? (
									<ArrowLeft className="h-6 w-6" />
								) : (
									<ArrowRight className="h-6 w-6" />
								)}
							</button>
						</div>
					</div>
				</div>
			</div>
		</section>
	);
}
